@@ -1,21 +1,7 @@
-/***************************************************************************
-                              kwqtablemodel.cpp
-                             -------------------
-
-    begin                : Mon Feb 27 18:27:30 PST 2006
-    copyright            : (C) 2006-2010 by Peter Hedlund
-    email                : peter.hedlund@kdemail.net
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006-2010 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kwqtablemodel.h"
 
@@ -142,7 +128,7 @@ bool KWQTableModel::setData(const QModelIndex & index, const QVariant & value, i
       break;
   }
 
-  emit dataChanged(index, index);
+  Q_EMIT dataChanged(index, index);
   return true;
 }
 
@@ -168,7 +154,7 @@ bool KWQTableModel::setHeaderData(int section, Qt::Orientation orientation, cons
       documentSettings.save();
     }
 
-    emit headerDataChanged(orientation, section, section);
+    Q_EMIT headerDataChanged(orientation, section, section);
     return true;
   }
   return false;
